This function facilitates the uploading of one or more files to a new savepoint enabled folder in a remote Integral repository.
Usage
create_savepoint(
name,
file,
path,
dependencies = NULL,
type = "Analysis",
values,
reason = NULL,
url = getOption("integral_url")
)Arguments
- name
A character string specifying the name of the new savepoint enabled folder in the remote Integral repository.
- file
A character or character vector specifying the local file paths to be uploaded in the savepoint enabled folder.
- path
A character string specifying the destination path of an existing savepoint enabled container in the Integral repository. The savepoint folder
namewill become a subfolder inpath.- dependencies
A character or character vector specifying the path(s) of the savepoint dependency files in the remote Integral repository.
- type
A character string specifying the type of savepoint enabled folder, e.g.,
"Analysis". Seeget_folder_typesandget_folder_type_values.- values
A named character vector of configured metadata values associated with the folder
type.- reason
Optional character string describing the reason for the savepoint creation.
- url
A character string representing the base URL of the Integral repository. Defaults to
getOption("integral_url").